pub enum DecodingKey {
Hmac(Vec<u8>),
Rsa(RsaPublicKey),
}Expand description
All the different kind of keys we can use to decode a JWT This key can be re-used so make sure you only initialize it once if you can for better performance
Variants
Hmac(Vec<u8>)
Rsa(RsaPublicKey)
Implementations
If you’re using HMAC, use this.
If you’re using HMAC with a base64 encoded, use this.
Convenience function for JWKS implementors