#[non_exhaustive]
pub enum ErrorKind {
Show 19 variants InvalidToken, InvalidSignature, InvalidEcdsaKey, InvalidRsaKey, InvalidHmacSecret, InvalidAlgorithmName, InvalidKeyFormat, ExpiredSignature, InvalidIssuer, InvalidAudience, InvalidSubject, ImmatureSignature, InvalidAlgorithm, UnsupportedAlgorithm, UnsupportedKeyType, NoWorkingKey, Base64(DecodeError), Json(Error), Utf8(FromUtf8Error),
}
The specific type of an error.

This enum may grow additional variants, the #[non_exhaustive] attribute makes sure clients don’t count on exhaustive matching. (Otherwise, adding a new variant could break existing code.)

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.

InvalidToken

When a token doesn’t have a valid JWT shape

InvalidSignature

When the signature doesn’t match

InvalidEcdsaKey

When the secret given is not a valid ECDSA key

InvalidRsaKey

When the secret given is not a valid RSA key

InvalidHmacSecret

When the secret given is not a valid HMAC secret

InvalidAlgorithmName

When the algorithm from string doesn’t match the one passed to from_str

InvalidKeyFormat

When a key is provided with an invalid format

ExpiredSignature

When a token’s exp claim indicates that it has expired

InvalidIssuer

When a token’s iss claim does not match the expected issuer

InvalidAudience

When a token’s aud claim does not match one of the expected audience values

InvalidSubject

When a token’s aud claim does not match one of the expected audience values

ImmatureSignature

When a token’s nbf claim represents a time in the future

InvalidAlgorithm

When the algorithm in the header doesn’t match the one passed to decode or the encoding/decoding key used doesn’t match the alg requested

UnsupportedAlgorithm

When the algorithm is not supported

UnsupportedKeyType

When the key provided is unsupported

NoWorkingKey

No key matched the conditions and worked successfully

Base64(DecodeError)

An error happened when decoding some base64 text

Json(Error)

An error happened while serializing/deserializing JSON

Utf8(FromUtf8Error)

Some of the text was invalid UTF-8