Module jsonwebtoken_rustcrypto::crypto
source · [−]Expand description
Lower level functions, if you want to do something other than JWTs
Functions
Take the payload of a JWT, sign it using the algorithm given and return the base64 url safe encoded of the result.
Validates that the key can be used with the given algorithm
Compares the signature given with a re-computed signature for HMAC or using the public key for RSA/EC.